API
==============================================================================

Preprocessing
---------------------
.. automodule:: VIPCCA.preprocessing.preprocessing
   :members: 
   :undoc-members:
   :show-inheritance:


VIPCCA
---------------------

.. automodule:: VIPCCA.vipcca
   :members:
   :undoc-members:
   :show-inheritance:
